@@ -7,12 +7,14 @@ library(lubridate)
 test_that("class tests",{
   skip_on_cran()
 
-  expect_warning(create_insee_folder(), regexp = NA)
   expect_warning(insee:::.onLoad(), regexp = NA)
+  expect_warning(insee:::create_insee_folder(), regexp = NA)
+
+  Sys.setenv(INSEE_metadata_folder = "tempdir")
 
   Sys.setenv(INSEE_idbank_dataset_path = "https://www.insee.fr/en/statistiques/fichier/fake_file.zip")
   expect_equal(any(class(get_idbank_list("CLIMAT-AFFAIRES")) == 'data.frame'), TRUE)
-  Sys.setenv(INSEE_idbank_dataset_path = "https://www.insee.fr/en/statistiques/fichier/2868055/2020_correspondance_idbank_dimension.zip")
+  Sys.setenv(INSEE_idbank_dataset_path = "https://www.insee.fr/en/statistiques/fichier/2868055/2021_correspondance_idbank_dimension.zip")
 
   expect_equal(any(class(get_idbank_list("CLIMAT-AFFAIRES")) == 'data.frame'), TRUE)
   expect_equal(any(class(get_idbank_list(update = TRUE)) == 'data.frame'), TRUE)
@@ -22,8 +24,8 @@ test_that("class tests",{
   expect_equal(any(class(get_idbank_list()) == 'data.frame'), TRUE)
   Sys.setenv("INSEE_today_date" = as.character(lubridate::today()))
 
-  idbank_test1 = get_idbank_list() %>% slice(1) %>% pull(idbank)
-  idbank_test2 = get_idbank_list() %>% slice(2) %>% pull(idbank)
+  idbank_test1 = "001694056"
+  idbank_test2 = "001694057"
 
   expect_equal(any(class(get_idbank_list("CNA-2014-CPEB")) == 'data.frame'), TRUE)
   expect_equal(any(class(get_idbank_list("BALANCE-PAIEMENTS", "CNA-2014-CPEB",
@@ -48,11 +50,17 @@ test_that("class tests",{
 
   expect_is(get_insee_idbank(idbank_test1), "data.frame")
   expect_is(get_insee_idbank(), "NULL")
+  expect_is(get_insee_idbank(character(0)), "NULL")
 
   expect_is(get_insee_dataset(), "NULL")
   expect_is(get_insee_dataset("CNA-2014-CPEB",
                               filter = "A.CNA_CPEB.A38-CB.VAL.D39.VALEUR_ABSOLUE.FE.EUROS_COURANTS.BRUT",
                               lastNObservations = 1), "data.frame")
+  expect_is(get_insee_dataset("IPC-2015", filter = "M+A.........CVS..", startPeriod = "2015-03"), "data.frame")
+
+  expect_is(get_insee_dataset("IPC-2015", filter = "A..SO...VARIATIONS_A....BRUT..SO",
+                              includeHistory = TRUE, updatedAfter = "2017-07-11T08:45:00"), "data.frame")
+
   expect_error(get_insee_dataset(1))
   expect_error(get_insee_dataset(c("a", "b")))
 
@@ -87,8 +95,8 @@ test_that("class tests",{
 test_that("output tests",{
   skip_on_cran()
 
-  expect_equal(if_null_na(NULL), NA)
-  expect_equal(if_null_na(1), 1)
+  expect_equal(insee:::if_null_na(NULL), NA)
+  expect_equal(insee:::if_null_na(1), 1)
 
   idbank_test1 = get_idbank_list() %>% slice(1) %>% pull(idbank)
   idbank_test401 = get_idbank_list() %>% slice(1:401) %>% pull(idbank)
@@ -107,19 +115,25 @@ test_that("output tests",{
   expect_equal(nrow(split_title(get_insee_idbank(idbank_test1, firstNObservations = 1), lang = "fr")), 1)
   expect_equal(nrow(split_title(get_insee_idbank(idbank_test1, firstNObservations = 1), lang = "en")), 1)
   expect_equal(nrow(get_insee_idbank(idbank_test401, firstNObservations = 1)), length(idbank_test401))
+
+  # expect_equal(any(class(get_insee_idbank(idbank_test401, firstNObservations = 1)) == 'data.frame'), TRUE)
   expect_message(nrow(get_insee_idbank(idbank_test401, firstNObservations = 1)))
 
   expect_equal(nrow(get_insee_idbank(idbank_test1201, firstNObservations = 1, limit = FALSE)), length(idbank_test1201))
+  # expect_equal(any(class(get_insee_idbank(idbank_test1201, firstNObservations = 1, limit = FALSE)) == 'data.frame'), TRUE)
   expect_is(get_insee_idbank(idbank_test1201, firstNObservations = 1), "NULL")
   expect_message(get_insee_idbank(idbank_test1201, firstNObservations = 1))
 
+  df = read_sdmx_slow("https://bdm.insee.fr/series/sdmx/data/IPC-2015/M.IPC.SO.SO.4000.INDICE.ENSEMBLE.FE.SO.BRUT.2015")
+  expect_is(df, "NULL")
+
   expect_equal(nrow(get_insee_idbank("001769682")) <
                  nrow(get_insee_idbank("001769682", includeHistory = TRUE)), TRUE)
 
-  expect_equal(nrow(get_insee_dataset("IPC-2015", filter = "M......ENSEMBLE...CVS.2015")) <
+  expect_equal(nrow(get_insee_dataset("IPC-2015", filter = "M......ENSEMBLE...CVS.2015.")) <
                  nrow(get_insee_dataset(
                    "IPC-2015",
-                   filter = "M......ENSEMBLE...CVS.2015",
+                   filter = "M......ENSEMBLE...CVS.2015.",
                    includeHistory = TRUE,
                    updatedAfter = "2017-07-11T08:45:00")), TRUE)
 
@@ -153,9 +167,11 @@ test_that("output tests",{
   df_fast = read_sdmx_fast(link)
   expect_equal(all(names(df_slow) == names(df_fast)), TRUE)
 
-  expect_warning(clean_insee_folder(), regexp = NA)
-  expect_equal(read_dataset_metadata("CLIMAT-AFFAIRES"), TRUE)
+  # expect_warning(clean_insee_folder(), regexp = NA)
+  # expect_equal(read_dataset_metadata("CLIMAT-AFFAIRES"), TRUE)
   expect_equal('data.frame' %in% class(get_dimension_values('CL_NATURE', 'NATURE', name = TRUE)), TRUE)
 
+  # delete all remaining files
+  # clean_insee_folder()
 })
 
